@@ -58,7 +58,7 @@ class TimeserverConfiguration(File):
                         keys["servers"].append(v.strip())
                     else:
                         keys[k] = v.strip()
-                except:
+                except Exception:
                     k = line
                     keys[k] = True
 
@@ -115,7 +115,7 @@ class TimeserverConfiguration(File):
         if not hasattr(self, 'keys'):
             self._parse()
 
-        for k, v in self.keys.iteritems():
+        for k, v in self.keys.items():
             if k == "servers":
                 for server in self.keys["servers"]:
                     contents += "server {server}\n".format(server=server)
@@ -158,10 +158,10 @@ class Ntp(TimeserverConfiguration):
     >>> print(ntp._configuration)
     # This file has been migrated or modified by imgbased
     <BLANKLINE>
-    restrict default kod nomodify notrap nopeer noquery
-    driftfile /var/lib/ntp/drift
     server 1.2.3.6
     server 1.2.3.7
+    driftfile /var/lib/ntp/drift
+    restrict default kod nomodify notrap nopeer noquery
     <BLANKLINE>
     """
 
@@ -188,8 +188,8 @@ class Chrony(TimeserverConfiguration):
     >>> print(chrony._configuration)
     # This file has been migrated or modified by imgbased
     <BLANKLINE>
-    logdir /var/log/chrony
     pool 2.fedora.pool.ntp.org iburst
+    logdir /var/log/chrony
     <BLANKLINE>
     """
 
